#[non_exhaustive]pub enum ErrorKind {
Message(&'static str),
Msg(String),
Forward(ForwardData),
ForwardNS(Arc<[ForwardNSData]>),
Io(Error),
Proto(ProtoError),
Resolve(ResolveError),
Timeout,
RecursionLimitExceeded {
count: usize,
},
}Expand description
The error kind for errors that get returned in the crate
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Message(&'static str)
An error with an arbitrary message, referenced as &’static str
Msg(String)
An error with an arbitrary message, stored as String
Forward(ForwardData)
Upstream DNS authority returned a Referral to another nameserver in the form of an SOA record
ForwardNS(Arc<[ForwardNSData]>)
Upstream DNS authority returned a referral to another set of nameservers in the form of additional NS records.
Io(Error)
An error got returned from IO
Proto(ProtoError)
An error got returned by the hickory-proto crate
Resolve(ResolveError)
An error got returned by the hickory-proto crate
Timeout
A request timed out
RecursionLimitExceeded
Could not fetch all records because a recursion limit was exceeded
Implementations
Sourceimpl ErrorKind
impl ErrorKind
Sourcepub fn is_message(&self) -> bool
pub fn is_message(&self) -> bool
Returns true if this is a ErrorKind::Message, otherwise false
Sourcepub fn as_message_mut(&mut self) -> Option<&mut &'static str>
pub fn as_message_mut(&mut self) -> Option<&mut &'static str>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Message, otherwise None
Sourcepub fn as_message(&self) -> Option<&&'static str>
pub fn as_message(&self) -> Option<&&'static str>
Optionally returns references to the inner fields if this is a ErrorKind::Message, otherwise None
Sourcepub fn into_message(self) -> Result<&'static str, Self>
pub fn into_message(self) -> Result<&'static str, Self>
Returns the inner fields if this is a ErrorKind::Message, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_msg_mut(&mut self) -> Option<&mut String>
pub fn as_msg_mut(&mut self) -> Option<&mut String>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Msg, otherwise None
Sourcepub fn as_msg(&self) -> Option<&String>
pub fn as_msg(&self) -> Option<&String>
Optionally returns references to the inner fields if this is a ErrorKind::Msg, otherwise None
Sourcepub fn into_msg(self) -> Result<String, Self>
pub fn into_msg(self) -> Result<String, Self>
Returns the inner fields if this is a ErrorKind::Msg, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_forward(&self) -> bool
pub fn is_forward(&self) -> bool
Returns true if this is a ErrorKind::Forward, otherwise false
Sourcepub fn as_forward_mut(&mut self) -> Option<&mut ForwardData>
pub fn as_forward_mut(&mut self) -> Option<&mut ForwardData>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Forward, otherwise None
Sourcepub fn as_forward(&self) -> Option<&ForwardData>
pub fn as_forward(&self) -> Option<&ForwardData>
Optionally returns references to the inner fields if this is a ErrorKind::Forward, otherwise None
Sourcepub fn into_forward(self) -> Result<ForwardData, Self>
pub fn into_forward(self) -> Result<ForwardData, Self>
Returns the inner fields if this is a ErrorKind::Forward, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_forward_ns(&self) -> bool
pub fn is_forward_ns(&self) -> bool
Returns true if this is a ErrorKind::ForwardNS, otherwise false
Sourcepub fn as_forward_ns_mut(&mut self) -> Option<&mut Arc<[ForwardNSData]>>
pub fn as_forward_ns_mut(&mut self) -> Option<&mut Arc<[ForwardNSData]>>
Optionally returns mutable references to the inner fields if this is a ErrorKind::ForwardNS, otherwise None
Sourcepub fn as_forward_ns(&self) -> Option<&Arc<[ForwardNSData]>>
pub fn as_forward_ns(&self) -> Option<&Arc<[ForwardNSData]>>
Optionally returns references to the inner fields if this is a ErrorKind::ForwardNS, otherwise None
Sourcepub fn into_forward_ns(self) -> Result<Arc<[ForwardNSData]>, Self>
pub fn into_forward_ns(self) -> Result<Arc<[ForwardNSData]>, Self>
Returns the inner fields if this is a ErrorKind::ForwardNS, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_io_mut(&mut self) -> Option<&mut Error>
pub fn as_io_mut(&mut self) -> Option<&mut Error>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Io, otherwise None
Sourcepub fn as_io(&self) -> Option<&Error>
pub fn as_io(&self) -> Option<&Error>
Optionally returns references to the inner fields if this is a ErrorKind::Io, otherwise None
Sourcepub fn into_io(self) -> Result<Error, Self>
pub fn into_io(self) -> Result<Error, Self>
Returns the inner fields if this is a ErrorKind::Io, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_proto_mut(&mut self) -> Option<&mut ProtoError>
pub fn as_proto_mut(&mut self) -> Option<&mut ProtoError>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Proto, otherwise None
Sourcepub fn as_proto(&self) -> Option<&ProtoError>
pub fn as_proto(&self) -> Option<&ProtoError>
Optionally returns references to the inner fields if this is a ErrorKind::Proto, otherwise None
Sourcepub fn into_proto(self) -> Result<ProtoError, Self>
pub fn into_proto(self) -> Result<ProtoError, Self>
Returns the inner fields if this is a ErrorKind::Proto, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_resolve(&self) -> bool
pub fn is_resolve(&self) -> bool
Returns true if this is a ErrorKind::Resolve, otherwise false
Sourcepub fn as_resolve_mut(&mut self) -> Option<&mut ResolveError>
pub fn as_resolve_mut(&mut self) -> Option<&mut ResolveError>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Resolve, otherwise None
Sourcepub fn as_resolve(&self) -> Option<&ResolveError>
pub fn as_resolve(&self) -> Option<&ResolveError>
Optionally returns references to the inner fields if this is a ErrorKind::Resolve, otherwise None
Sourcepub fn into_resolve(self) -> Result<ResolveError, Self>
pub fn into_resolve(self) -> Result<ResolveError, Self>
Returns the inner fields if this is a ErrorKind::Resolve, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if this is a ErrorKind::Timeout, otherwise false
Sourcepub fn is_recursion_limit_exceeded(&self) -> bool
pub fn is_recursion_limit_exceeded(&self) -> bool
Returns true if this is a ErrorKind::RecursionLimitExceeded, otherwise false
Sourcepub fn as_recursion_limit_exceeded_mut(&mut self) -> Option<&mut usize>
pub fn as_recursion_limit_exceeded_mut(&mut self) -> Option<&mut usize>
Optionally returns mutable references to the inner fields if this is a ErrorKind::RecursionLimitExceeded, otherwise None
Sourcepub fn as_recursion_limit_exceeded(&self) -> Option<&usize>
pub fn as_recursion_limit_exceeded(&self) -> Option<&usize>
Optionally returns references to the inner fields if this is a ErrorKind::RecursionLimitExceeded, otherwise None
Sourcepub fn into_recursion_limit_exceeded(self) -> Result<usize, Self>
pub fn into_recursion_limit_exceeded(self) -> Result<usize, Self>
Returns the inner fields if this is a ErrorKind::RecursionLimitExceeded, otherwise returns back the enum in the Err case of the result