Enum hickory_recursor::error::ErrorKind
source · #[non_exhaustive]pub enum ErrorKind {
Message(&'static str),
Msg(String),
Forward(Name),
Io(Error),
Proto(ProtoError),
Resolve(ResolveError),
Timeout,
}Expand description
The error kind for errors that get returned in the crate
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Message(&'static str)
An error with an arbitrary message, referenced as &’static str
Msg(String)
An error with an arbitrary message, stored as String
Forward(Name)
Upstream DNS authority returned a Referral to another nameserver
Io(Error)
An error got returned from IO
Proto(ProtoError)
An error got returned by the hickory-proto crate
Resolve(ResolveError)
An error got returned by the hickory-proto crate
Timeout
A request timed out
Implementations
sourceimpl ErrorKind
impl ErrorKind
sourcepub fn is_message(&self) -> bool
pub fn is_message(&self) -> bool
Returns true if this is a ErrorKind::Message, otherwise false
sourcepub fn as_message_mut(&mut self) -> Option<&mut &'static str>
pub fn as_message_mut(&mut self) -> Option<&mut &'static str>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Message, otherwise None
sourcepub fn as_message(&self) -> Option<&&'static str>
pub fn as_message(&self) -> Option<&&'static str>
Optionally returns references to the inner fields if this is a ErrorKind::Message, otherwise None
sourcepub fn into_message(self) -> Result<&'static str, Self>
pub fn into_message(self) -> Result<&'static str, Self>
Returns the inner fields if this is a ErrorKind::Message, otherwise returns back the enum in the Err case of the result
sourcepub fn as_msg_mut(&mut self) -> Option<&mut String>
pub fn as_msg_mut(&mut self) -> Option<&mut String>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Msg, otherwise None
sourcepub fn as_msg(&self) -> Option<&String>
pub fn as_msg(&self) -> Option<&String>
Optionally returns references to the inner fields if this is a ErrorKind::Msg, otherwise None
sourcepub fn into_msg(self) -> Result<String, Self>
pub fn into_msg(self) -> Result<String, Self>
Returns the inner fields if this is a ErrorKind::Msg, otherwise returns back the enum in the Err case of the result
sourcepub fn is_forward(&self) -> bool
pub fn is_forward(&self) -> bool
Returns true if this is a ErrorKind::Forward, otherwise false
sourcepub fn as_forward_mut(&mut self) -> Option<&mut Name>
pub fn as_forward_mut(&mut self) -> Option<&mut Name>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Forward, otherwise None
sourcepub fn as_forward(&self) -> Option<&Name>
pub fn as_forward(&self) -> Option<&Name>
Optionally returns references to the inner fields if this is a ErrorKind::Forward, otherwise None
sourcepub fn into_forward(self) -> Result<Name, Self>
pub fn into_forward(self) -> Result<Name, Self>
Returns the inner fields if this is a ErrorKind::Forward, otherwise returns back the enum in the Err case of the result
sourcepub fn as_io_mut(&mut self) -> Option<&mut Error>
pub fn as_io_mut(&mut self) -> Option<&mut Error>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Io, otherwise None
sourcepub fn as_io(&self) -> Option<&Error>
pub fn as_io(&self) -> Option<&Error>
Optionally returns references to the inner fields if this is a ErrorKind::Io, otherwise None
sourcepub fn into_io(self) -> Result<Error, Self>
pub fn into_io(self) -> Result<Error, Self>
Returns the inner fields if this is a ErrorKind::Io, otherwise returns back the enum in the Err case of the result
sourcepub fn as_proto_mut(&mut self) -> Option<&mut ProtoError>
pub fn as_proto_mut(&mut self) -> Option<&mut ProtoError>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Proto, otherwise None
sourcepub fn as_proto(&self) -> Option<&ProtoError>
pub fn as_proto(&self) -> Option<&ProtoError>
Optionally returns references to the inner fields if this is a ErrorKind::Proto, otherwise None
sourcepub fn into_proto(self) -> Result<ProtoError, Self>
pub fn into_proto(self) -> Result<ProtoError, Self>
Returns the inner fields if this is a ErrorKind::Proto, otherwise returns back the enum in the Err case of the result
sourcepub fn is_resolve(&self) -> bool
pub fn is_resolve(&self) -> bool
Returns true if this is a ErrorKind::Resolve, otherwise false
sourcepub fn as_resolve_mut(&mut self) -> Option<&mut ResolveError>
pub fn as_resolve_mut(&mut self) -> Option<&mut ResolveError>
Optionally returns mutable references to the inner fields if this is a ErrorKind::Resolve, otherwise None
sourcepub fn as_resolve(&self) -> Option<&ResolveError>
pub fn as_resolve(&self) -> Option<&ResolveError>
Optionally returns references to the inner fields if this is a ErrorKind::Resolve, otherwise None
sourcepub fn into_resolve(self) -> Result<ResolveError, Self>
pub fn into_resolve(self) -> Result<ResolveError, Self>
Returns the inner fields if this is a ErrorKind::Resolve, otherwise returns back the enum in the Err case of the result
sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if this is a ErrorKind::Timeout, otherwise false